@@ -10,7 +10,7 @@ use Cwd;
 use File::Path;
 our @ISA = qw( Module::Build );
 
-our $VERSION ='0.35';
+our $VERSION ='0.39';
 
 sub process_xs_files {
 	my $self = shift;
@@ -158,11 +158,12 @@ sub hipi_do_depends {
         zlib1g-dev
         libperl-dev
         libio-epoll-perl
+		libwebkitgtk-1.0-0
     );
 	
 	
 	if ( $self->hipi_build_target eq 'wheezy') {
-        push @debs, ( 'libopengl-perl', 'libthreads-perl','libthreads-shared-perl','libthread-queue-perl' );
+        push @debs, ( 'libthreads-perl','libthreads-shared-perl','libthread-queue-perl' );
     }
     
     
