@@ -2,7 +2,7 @@
 # Package       HiPi::Apps::Control::MainWindow
 # Description:  Main Window for HiPi Apps Control
 # Created       Mon Feb 25 13:29:44 2013
-# SVN Id        $Id: MainWindow.pm 13 2015-03-29 21:36:38Z Mark Dootson $
+# SVN Id        $Id: MainWindow.pm 59 2016-03-07 23:56:05Z Mark Dootson $
 # Copyright:    Copyright (c) 2013 Mark Dootson
 # Licence:      This work is free software; you can redistribute it and/or modify it 
 #               under the terms of the GNU General Public License as published by the 
@@ -64,7 +64,7 @@ sub new {
     # Controls
     #-----------------------------------------------------------
     
-    my $selectpanelclass = ( system_is_raspberry_2 ) ? 'HiPi::Apps::Control::SelectPanel2' : 'HiPi::Apps::Control::SelectPanel';
+    my $selectpanelclass = ( HiPi::RaspberryPi::get_piboard_rev == 3 ) ? 'HiPi::Apps::Control::SelectPanel2' : 'HiPi::Apps::Control::SelectPanel';
     #$selectpanelclass = 'HiPi::Apps::Control::SelectPanel';
     $selectpanelclass->require;
     my $framepanel = Wx::Panel->new($self, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxTAB_TRAVERSAL|wxBORDER_NONE );
