@@ -2,7 +2,7 @@
 # Package       HiPi::Apps::Control::Panel::RInfo
 # Description:  General Info Panel
 # Created       Wed Feb 27 23:09:33 2013
-# SVN Id        $Id: RInfo.pm 1076 2013-03-13 08:55:10Z Mark Dootson $
+# SVN Id        $Id: RInfo.pm 37 2016-03-07 01:14:41Z Mark Dootson $
 # Copyright:    Copyright (c) 2013 Mark Dootson
 # Licence:      This work is free software; you can redistribute it and/or modify it 
 #               under the terms of the GNU General Public License as published by the 
@@ -109,7 +109,7 @@ sub SetWindowValue {
     
     my $index = 0;
     
-    for my $key ( qw( Model Memory Manufacturer Release ) )
+    for my $key ( qw( Model Memory Processor Hardware Manufacturer Release Serial ) )
     {
         my $id = $list->InsertImageStringItem( $index, $key, -1);
         my $dkey = lc($key);
@@ -117,7 +117,7 @@ sub SetWindowValue {
         $index ++;
     }
     {
-        my $id = $list->InsertImageStringItem( $index, 'GPIO Revision', -1);
+        my $id = $list->InsertImageStringItem( $index, 'Board Revision', -1);
         $list->SetItem($id, 1, $data->{revision}, -1 );
         $index ++;
     }
@@ -128,12 +128,12 @@ sub SetWindowValue {
     #    #$list->SetItem($id, 1, '/proc/cpuinfo', -1 );
     #    $index ++;
     #}
-    for my $key ( sort keys( %{ $data->{cpuinfo} } )) {
-        next if $key eq 'GPIO Revision';
-        my $id = $list->InsertImageStringItem( $index, $key, -1);
-        $list->SetItem($id, 1, $data->{cpuinfo}->{$key}, -1 );
-        $index ++
-    }
+    #for my $key ( sort keys( %{ $data->{cpuinfo} } )) {
+    #    next if $key eq 'GPIO Revision';
+    #    my $id = $list->InsertImageStringItem( $index, $key, -1);
+    #    $list->SetItem($id, 1, $data->{cpuinfo}->{$key}, -1 );
+    #    $index ++
+    #}
     
     
     
